<?php

namespace Drupal\session_management\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configuration class for saving auto logout feature configuration.
 */
class AutoLogoutSettingsForm extends ConfigFormBase {

  public const SETTINGS = 'session_management.settings';

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [static::SETTINGS];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'autologout-settings-form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $form['libraries'] = [
      '#attached' => [
        'library' => [
          "session_management/session_management.mo_session",
        ],
      ],
    ];

    $form['#disabled'] = TRUE;

    $form['div_start'] = [
      '#type' => 'markup',
      '#markup' => '<div class="mo-table-layout-2"><div class="mo-table-layout-3 mo-container1">',
    ];

    $form['browser_session_destroy'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable user session destroy'),
      '#description' => $this->t('Enable this if you want to terminate the user session after the browser is closed.'),
    ];

    $form['auto_logout_detail'] = [
      '#type' => 'details',
      '#title' => t('User Auto Logout Settings [<i>Coming Soon</i>]'),
      '#open' => TRUE,
    ];

    $form['auto_logout_detail']['autologout_enabled'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable Autologout'),
      '#description' => $this->t('Enable autologout on the site.'),
      '#default_value' => FALSE,
    ];

    $form['auto_logout_detail']['autologout_timeout'] = [
      '#type' => 'number',
      '#title' => $this->t('Logout Timeout (in seconds)'),
      '#description' => $this->t('The duration of user inactivity (in seconds), that triggers the display of a logout notification dialog.'),
      '#min' => '50',
      '#default_value' => 50,
    ];

    $form['auto_logout_detail']['autologout_response_time'] = [
      '#type' => 'number',
      '#title' => $this->t('Response Time (in seconds)'),
      '#description' => $this->t('The time allowed for user response to the logout dialog box'),
      '#min' => '5',
      '#default_value' => 5,
    ];

    $form['auto_logout_detail']['force_logout'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Force Logout'),
      '#description' => $this->t('Logout the user regardless of their activity.'),
    ];

    $form['auto_logout_detail']['modal_info'] = [
      '#type' => 'details',
      '#title' => $this->t('Modal Dialog Info'),
    ];

    $form['auto_logout_detail']['modal_info']['mo_modal_width'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Modal Custom width'),
      '#default_value' => 400,
      '#size' => 40,
      '#description' => $this->t('Enter the width of the modal dialog in pixels.'),
    ];

    $form['auto_logout_detail']['modal_info']['mo_modal_title'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Modal Custom Title'),
      '#required' => TRUE,
      '#default_value' => "Drupal Logout Alert",
      '#size' => 40,
      '#description' => $this->t('Enter the width of the modal dialog in pixels.'),
    ];

    $form['auto_logout_detail']['modal_info']['mo_modal_message'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Modal Custom Message'),
      '#required' => TRUE,
      '#default_value' => "You've been inactive for a while. Would you like to continue your session?",
      '#size' => 40,
      '#description' => $this->t('Enter the message to display in the logout modal dialog.'),
    ];

    $form['auto_logout_detail']['modal_info']['mo_modal_yes_button_text'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Modal Custom Confirm button text'),
      '#required' => TRUE,
      '#default_value' => "Accept",
      '#size' => 40,
      '#description' => $this->t('Enter the confirmation button text to <b>extend</b> the user session.'),
    ];

    $form['auto_logout_detail']['modal_info']['mo_modal_no_button_text'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Modal Custom Decline button text'),
      '#required' => TRUE,
      '#default_value' => "Deny",
      '#size' => 40,
      '#description' => $this->t('Enter the confirmation button text to <b>end</b> the user session.'),
    ];

    $form['auto_logout_detail']['role_based_logout'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Role Based Logout'),
    ];

    $roles = \Drupal::entityTypeManager()->getStorage('user_role')->loadMultiple();
    $option = [];

    foreach ($roles as $role) {
      $option[$role->getOriginalId()] = $role->label();
    }
    unset($option['anonymous']);
    unset($option['authenticated']);

    $rows = [
      [
        'roles' => [
          'data' => [
            '#type' => 'select',
            '#options' => $option,
          ],
        ],
        'logout_time' => [
          'data' => [
            '#type' => 'number',
            '#min' => '5',
            '#default_value' => 50,
          ],
        ],
      ],
    ];

    $form['auto_logout_detail']['role_based_logout_table'] = [
      '#type' => 'table',
      '#header' => [
        'roles' => $this->t('Select Role') ,
        'logout_time' => $this->t('Logout Time'),
      ],
      '#rows' => $rows,
    ];

    $form['auto_logout_detail']['add_rows'] = [
      '#type' => 'submit',
      '#button_type' => 'primary',
      '#value' => $this->t('Add row +'),
    ];

    $form['auto_logout_detail']['redirect_after_logout'] = [
      '#type' => 'url',
      '#title' => $this->t('Redirect After Logout'),
      '#default_value' => '/user/login',
    ];

    $form['config_save_button'] = [
      '#type' => 'submit',
      '#button_type' => 'primary',
      '#value' => $this->t('Save Configuration'),
      '#disabled' => TRUE
    ];

    $form['div_end'] = [
      '#type' => 'markup',
      '#markup' => '</div></div>',
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {

  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
  }

}
